@@ -46,15 +46,18 @@ sub generate_conf {
             HAVE_UNISTD_H        unistd.h
         ));
 
-        try_getdtablesize ($check, \$longest, $defines);
-        try_getentropy    ($check, \$longest, $defines);
-        try_getrandom     ($check, \$longest, $defines);
-        try_getrlimit     ($check, \$longest, $defines);
-        try_jrand48       ($check, \$longest, $defines);
-        try_srandom       ($check, \$longest, $defines);
-        try_sysconf       ($check, \$longest, $defines);
+        try_getdtablesize  ($check, \$longest, $defines);
+        try_getentropy     ($check, \$longest, $defines);
+        try_getrandom      ($check, \$longest, $defines);
+        try_getrlimit      ($check, \$longest, $defines);
+        try_jrand48        ($check, \$longest, $defines);
+        try_srandom        ($check, \$longest, $defines);
+        try_sysconf        ($check, \$longest, $defines);
 
-        try_sa_len        ($check, \$longest, $defines);
+        try_sa_len         ($check, \$longest, $defines);
+
+        # this must come after HAVE_SYS_TIME_H check
+        try_struct_timeval ($check, \$longest, $defines);
     }
 
 #
@@ -313,12 +316,53 @@ sub try_sa_len {
     }
 }
 
+sub try_struct_timeval {
+    my ($check, $long, $defs) = @_;
+    my $msg = join ' ', 'Checking struct timeval';
+    my $len = length $msg;
+    if ($check) { $$long = $len if $len > $$long; return; }
+    my $more = $$long - $len;
+
+    my $iswin = $^O eq 'MSWin32'; # need Cygwin too?
+    my $havesystimeh = grep {/define HAVE_SYS_TIME_H/} @$defs;
+
+    if ( check_lib(
+        header   => [
+            (( !$iswin || $havesystimeh )
+                ? 'sys/time.h'
+                : ()
+            ),
+            'time.h'
+        ],
+        #lib      => 'c', # wont link against libc
+        debug    => 0,
+        function => q{
+            struct timeval tv;
+            tv.tv_sec  = 0;
+            tv.tv_usec = 0;
+            return 0;
+        },
+    )) {
+        # do nothing. we found it.
+        print $msg, ' ..', '.'x$more, ' found';
+    }
+    else {
+        push @$defs, 'struct timeval { long tv_sec; long tv_usec; };';
+        print $msg, ' ..', '.'x$more, ' missing';
+    }
+}
+
 sub write_conf {
     my ($defines, $outfile) = @_;
 
     open my $fh, '>', $outfile
         or die 'open: ', $outfile, ": $!";
 
+    print $fh '#ifndef EUMM_H';
+    print $fh '#define EUMM_H';
+
     print $fh $_
         for @$defines;
+
+    print $fh '#endif  /* EUMM_H */';
 }
